@@ -1489,7 +1489,8 @@ void inpaint(Imagefloat *img, const array2D<float> &mask, float threshold, int r
             rescaleBilinear(asrc, adst, multithread);
         }
 
-        Inpainting op(img, mask, threshold, radius / skip, border / skip, limit / skip, multithread);
+        int radius_scaled = radius > 0 ? std::max(radius / skip, 1) : 0;
+        Inpainting op(&tmp, tmpm, threshold, radius_scaled, border / skip, limit / skip, multithread);
         op();
 
         array2D<float> r(dW, dH, tmp.r.ptrs, ARRAY2D_BYREFERENCE);
@@ -1497,7 +1498,6 @@ void inpaint(Imagefloat *img, const array2D<float> &mask, float threshold, int r
         array2D<float> b(dW, dH, tmp.b.ptrs, ARRAY2D_BYREFERENCE);
         float t = std::abs(threshold);
         float cs = float(dW) / float(W);
-        float rs = float(dH) / float(H);
         bool inv = threshold < 0;
         for (int y = 0; y < H; ++y) {
             for (int x = 0; x < W; ++x) {
