@@ -46,7 +46,7 @@ LensProfilePanel::LensProfilePanel() :
     lensfunAutoChanged(false),
     lensfunCameraChanged(false),
     lensfunLensChanged(false),
-    allowFocusDep(true),
+    //allowFocusDep(true),
     isRaw(true),
     metadata(nullptr),
     modesGrid(Gtk::manage(new Gtk::Grid())),
@@ -60,7 +60,7 @@ LensProfilePanel::LensProfilePanel() :
     lensfunCameras(Gtk::manage((new MyComboBox()))),
     lensfunLensesLbl(Gtk::manage((new Gtk::Label(M("EXIFFILTER_LENS"))))),
     lensfunLenses(Gtk::manage((new MyComboBox()))),
-    warning(Gtk::manage(new RTImage("warning.png"))),
+    warning(Gtk::manage(new RTImage("warning.svg"))),
     ckbUseDist(Gtk::manage((new Gtk::CheckButton(M("TP_LENSPROFILE_USE_GEOMETRIC"))))),
     ckbUseVign(Gtk::manage((new Gtk::CheckButton(M("TP_LENSPROFILE_USE_VIGNETTING"))))),
     ckbUseCA(Gtk::manage((new Gtk::CheckButton(M("TP_LENSPROFILE_USE_CA")))))
